package v2

import (
	"k8s.io/apimachinery/pkg/apis/meta/v1/unstructured"
	"k8s.io/apimachinery/pkg/runtime"
	"quark.netapp.io/volume-controller/pkg/quarkconfig"
)

var annotationMap map[string]string

// This function adds correlation id to the annotation of any
// K8s objects.
func (*NVCClient) AddCorrelationID(id string, obj runtime.Object) error {

	u := &unstructured.Unstructured{}

	objMap, err := runtime.DefaultUnstructuredConverter.ToUnstructured(&obj)
	if err != nil {
		return err
	}
	u.SetUnstructuredContent(objMap)
	// Get the current Map.
	annotationMap = u.GetAnnotations()
	if annotationMap == nil {
		annotationMap = make(map[string]string)
	}
	annotationMap[quarkconfig.SDECorUUID] = id
	// Set correlation id
	u.SetAnnotations(annotationMap)
	// Convert the unstructured to runtime object.
	return runtime.DefaultUnstructuredConverter.FromUnstructured(u.Object, obj)

}

// This function removes correlation id from the annotation of any
// K8s objects.
func (*NVCClient) ClearCorrelationID(obj runtime.Object) error {
	u := &unstructured.Unstructured{}

	objMap, err := runtime.DefaultUnstructuredConverter.ToUnstructured(&obj)
	if err != nil {
		return err
	}
	u.SetUnstructuredContent(objMap)
	// Get the current Map.
	annotationMap = u.GetAnnotations()
	if annotationMap == nil {
		return nil
	}

	delete(annotationMap, quarkconfig.SDECorUUID)
	// Set correlation id
	u.SetAnnotations(annotationMap)
	// Convert the unstructured to runtime object.
	return runtime.DefaultUnstructuredConverter.FromUnstructured(u.Object, obj)

}
